package com.jz.dmp.modules.dao;

import com.jz.common.constant.JsonResult;
import com.jz.dmp.modules.controller.DataIntegration.bean.DataSourceNameListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.RealTimeSyncListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.RealTimeSyncListReq;
import com.jz.dmp.modules.model.DmpRealtimeSyncInfo;
import com.jz.dmp.modules.model.RealTimeSyncDataSourceModel;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 实时同步任务(DmpRealtimeSyncInfo)表数据库访问层
 *
 * @author Bellamy
 * @since 2021-01-05 14:18:03
 */
public interface DmpRealtimeSyncInfoDao {

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    DmpRealtimeSyncInfo queryById(Integer id);

    /**
     * 查询指定行数据
     *
     * @param offset 查询起始位置
     * @param limit  查询条数
     * @return 对象列表
     */
    List<DmpRealtimeSyncInfo> queryAllByLimit(@Param("offset") int offset, @Param("limit") int limit);


    /**
     * 通过实体作为筛选条件查询
     *
     * @param dmpRealtimeSyncInfo 实例对象
     * @return 对象列表
     */
    List<DmpRealtimeSyncInfo> queryAll(DmpRealtimeSyncInfo dmpRealtimeSyncInfo);

    /**
     * 新增数据
     *
     * @param dmpRealtimeSyncInfo 实例对象
     * @return 影响行数
     */
    int insert(DmpRealtimeSyncInfo dmpRealtimeSyncInfo);

    /**
     * 批量新增数据（MyBatis原生foreach方法）
     *
     * @param entities List<DmpRealtimeSyncInfo> 实例对象列表
     * @return 影响行数
     */
    int insertBatch(@Param("entities") List<DmpRealtimeSyncInfo> entities);

    /**
     * 批量新增或按主键更新数据（MyBatis原生foreach方法）
     *
     * @param entities List<DmpRealtimeSyncInfo> 实例对象列表
     * @return 影响行数
     */
    int insertOrUpdateBatch(@Param("entities") List<DmpRealtimeSyncInfo> entities);

    /**
     * 修改数据
     *
     * @param dmpRealtimeSyncInfo 实例对象
     * @return 影响行数
     */
    int update(DmpRealtimeSyncInfo dmpRealtimeSyncInfo);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 影响行数
     */
    int deleteById(Integer id);

    /**
     * 实时同步任务列表分页查询
     *
     * @return
     */
    List<RealTimeSyncListDto> queryRealTimeSyncListPage(RealTimeSyncListReq req) throws Exception;

    List<DmpRealtimeSyncInfo> queryListById(@Param("ids") String[] ids) throws Exception;

    /**
     * 获取数据源和目标数据源下拉框
     *
     * @return
     * @author Bellamy
     * @since 2021-01-06
     */
    List<DataSourceNameListDto> queryDatasourceNameList(@Param("projectId") String projectId, @Param("type") String type) throws Exception;

    /**
     * 根据数据源id获取数据信息
     *
     * @return
     * @author Bellamy
     * @since 2021-01-06
     */
    RealTimeSyncDataSourceModel querygSourceDbInfoById(@Param("srcDataSourceId") String srcDataSourceId) throws Exception;

    List<Map> queryRealTimeInfoByDataSourceId(@Param("srcDatasourceId") String srcDatasourceId, @Param("targetDatasourceId") String targetDatasourceId);

    /**
     * 查询源数据源的黑名单表
     *
     * @return
     * @author Bellamy
     * @since 2021-01-06
     */
    Map queryBlackTableByDataSourceId(@Param("srcDatasourceId") String srcDatasourceId);
}